/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  "Alkalmazás"
 ,"Alkalmazások"

]
, "User, Users"
: [
  "Felhasználó"
 ,"Felhasználók"

]
, "Groups"
: "Csoportok"

, "Roles"
: "Szerepek"

, "Applications"
: "Alkalmazások"

, "Containers"
: "Konténerek"

, "Shared Tags"
: "Megosztott címkék"

, "Customfields"
: "Egyedi mezők"

, "Computers"
: "Számítógépek"

, "Access Log, Access Logs"
: [
  "Hozzáférési Napló"
 ,"Hozzáférési Napló"

]
, "Log"
: ""

, "Server Information"
: "Szerver információ"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Admin"

, "Refresh"
: "Frissítés"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Alapértelmezett Címjegyzék új kapcsolatokhoz és csoportokhoz"

, "Computer Name"
: "Számítógép Név"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Leírás"

, "Name"
: "Név"

, "Label"
: "Osztályozás"

, "Value"
: "Érték"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Csoport neve"

, "Visibility"
: "Láthatóság"

, "Display in addressbook"
: "Megjelenítés a címjegyzékben"

, "Hide from addressbook"
: "Elrejtés a címjegyzékben"

, "Saved in Addressbook"
: "Címjegyzékben mentve"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Csoport tagok"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domain nem engedélyezett. Nézd meg az SMTP domain konfigurációt."

, "Confirm"
: "Megerősít"

, "Do you really want to delete the selected tags?"
: "Biztos törölni akarja a kiválaszott címkéket?"

, "Deleting tag(s)..."
: "Címke(ék) törlése..."

, "Add Tag"
: "Címke hozzáadása"

, "Edit Tag"
: "Címke szerkesztése"

, "Delete Tag"
: "Címke törlése"

, "Search:"
: "Keresés:"

, "Displaying tags {0} - {1} of {2}"
: "Címkék megjelenítése {0} - {1} / {2}"

, "No tags to display"
: "Nincs megjeleníthető címke"

, "ID"
: "ID"

, "Color"
: "Szín"

, "Usage:&#160;"
: "Használat:&#160;"

, "Do you really want to delete the selected roles?"
: "Biztos törölni akarod a kiválasztott szerepeket?"

, "Deleting role(s)..."
: "Szerep(ek) törlése..."

, "Failed"
: "Nem sikerült"

, "Some error occurred while trying to delete the role."
: "Valamilyen hiba történt a szerep mentése közben."

, "Add Role"
: "Szabály hozzáadása"

, "Edit Role"
: "Szabály szerkesztése"

, "Delete Role"
: "Szabály törlése"

, "Displaying roles {0} - {1} of {2}"
: "Szerepek megjelenítése{0} - {1} / {2}"

, "No roles to display"
: "Nincs megjelenthető szerep"

, "Container Name"
: "Konténer Név"

, "Type"
: "Típus"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Konténer"
 ,"Konténerek"

]
, "Model"
: "Modell"

, "personal"
: "személyes"

, "shared"
: "megosztott"

, "Order"
: "Sorrend"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Feljegyzés a tulajdonosnak"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Valóban törölni akarja a kiválasztott csoportokat?"

, "Deleting group(s)..."
: "Csoport(ok) törlése..."

, "Some error occurred while trying to delete the group."
: "Valamilyen hiba történt a csoport törlése közben."

, "Add Group"
: "Csoport hozzáadása"

, "Edit Group"
: "Csoport szerkesztése"

, "Delete Group"
: "Csoport törlése"

, "Displaying groups {0} - {1} of {2}"
: "Csoportok megjelenítése {0} - {1} / {2}"

, "No groups to display"
: "Nincs megjeleníthető csoport"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP Cím"

, "Login Time"
: "Bejelentkezés ideje"

, "Logout Time"
: "Kijelentkezés ideje"

, "Client Type"
: "Kliens típus"

, "Session ID"
: "Hozzáférés ID"

, "Login Name"
: "Bejelentkezési név"

, "Result"
: "Eredmény"

, "User Agent"
: ""

, "user blocked"
: "felhasználó blokkolva"

, "password expired"
: "jelszó lejárt"

, "user disabled"
: "felhasználó letiltva"

, "invalid password"
: "érvénytelen jelszó"

, "ambiguous username"
: "kétértelmű felhasználó név"

, "user not found"
: "felhasználó nem található"

, "failure"
: "hiba"

, "success"
: "siker"

, "Customfield, Customfields"
: [
  "Egyedi mező"
 ,"Egyedi mezők"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Hibák"

, "Please configure store for this field type"
: "Kérlek állítsd be ennek a mező típusnak a tárolását"

, "Record Class"
: "Adat osztály"

, "Given record class not found"
: "Megadott adat osztály nem találató"

, "Cancel"
: "Megszakítás"

, "OK"
: "OK"

, "Configure store"
: "Tárolás beállítása"

, "Custom field definition"
: "Egyedi mező leírás"

, "Text"
: "Szöveg"

, "Textarea"
: ""

, "Number"
: "Szám"

, "Date"
: "Dátum"

, "DateTime"
: "DátumIdő"

, "Time"
: "Idő"

, "Boolean"
: "Logikai"

, "Search Combo"
: "Kombó kerés"

, "Key Field"
: "Kulcs mező"

, "Record"
: "Adat"

, "Record List"
: ""

, "Length"
: "Hossz"

, "Required"
: "Szükséges"

, "Custom field additional properties"
: "Egyedi mező további beállításai"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Csoport"
 ,"Csoport"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Egyedi mező már létezik. Kérlek válassz egy másik nevet."

, "Enable Account"
: "Fiók engedélyezése"

, "Disable Account"
: "Fiók törlése"

, "Reset Password"
: "Jelszó visszaállítása"

, "Status"
: "Állapot"

, "Display name"
: "Megjelenítési név"

, "Login name"
: "Bejelentkezési név"

, "Last name"
: "Vezetéknév"

, "First name"
: "Keresztnév"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Utolsó bejelentkezés"

, "Last login from"
: "Utolsó bejelentkezés helye"

, "Password Must Change"
: "A jelszót meg kell változtatni"

, "Password changed"
: "Jelszó megváltoztatása"

, "Expires"
: "Lejár"

, "Set new password"
: "Új jelszó beállítása"

, "Please enter the new password:"
: "Kérjük adja meg az új jelszavat:"

, "Users"
: "Felhasználók"

, "Samba User, Samba Users"
: [
  "Samba User"
 ,"Samba Users"

]
, "Email User, Email Users"
: [
  "Email User"
 ,"Email Users"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "A jelszavak nem egyeznek!"

, "Passwords match!"
: "Jelszó megegyezik!"

, "Primary group"
: "Elsődleges csoport"

, "Unix"
: "Unix"

, "Home Directory"
: "Home könyvtár"

, "Login Shell"
: "Bejelentkezési Környezet"

, "Windows"
: "Windows"

, "Home Drive"
: "Home meghajtó"

, "never logged in"
: "sosem jelentkezett be"

, "Home Path"
: "Home útvonal"

, "never logged off"
: "sosem jelentkezett ki"

, "Profile Path"
: "Profil útvonal"

, "Password Last Set"
: "Utolsónak megadott jelszó"

, "never"
: "soha"

, "Logon Script"
: "Bejelentkezési Script"

, "Password Can Change"
: "A jelszó megváltozhat"

, "not set"
: "nincs beállítva"

, "Kick Off Time"
: "Kirúgás ideje"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvóta"

, "no quota set"
: "nincs kvóta beállítva"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Mostani Postafiók mérete"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Mostani Sieve mérete"

, "Information"
: "Információ"

, "Last Login"
: "Utolsó bejelentkezés"

, "Forward Only"
: "Csak továbbítás"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Aliasz cím hozzáadása..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Domain nem engedélyezett"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "Továbbítás magamnak"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Jelszó megerősítés"

, "Repeat password"
: "Jelszó ismétlése"

, "Ok"
: "OK"

, "Account"
: "Fiók"

, "Password"
: "Jelszó"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "engedélyezve"

, "disabled"
: "felfüggesztve"

, "expired"
: "lejárt"

, "blocked"
: "blokkolt"

, "Invalid Status"
: "Érvénytelen állapot"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "A blokkolt állapot csak akkor él, ha egy felhasználó túl gyakran próbált meg rossz jelszóval bejelentkezni. Itt nem lehetséges ezt az állapotot beállítani."

, "don't know"
: "nem tudom"

, "Password set"
: "Beállított jelszó"

, "User groups"
: "Felhasználói csoportok"

, "User roles"
: "Felhasználó szerepek"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Számítógép"
 ,"Számítógépek"

]
, "Please wait"
: "Kérlek várj"

, "Updating Memberships"
: "Tagságok frissítése"

, "Could not save role."
: "Szerep mentése nem sikerült."

, "Please fix the errors noted."
: "Kérjük javítsa kis a jelölt hibákat."

, "Deleting role..."
: "Szerep törlése..."

, "Rights"
: "Jogok"

, "Members"
: "Tagok"

, "Role Name"
: "Szerep neve"

, "Transferring {0}..."
: "{0} átvitele..."

, "Role"
: "Szerep"

, "Add New Role"
: "Új szerep hozzáadása"

, "Edit Role \"{0}\""
: "Szerep szerkesztése \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Címke frissítése"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Megengedett kontextus"

, "Context"
: "Kontextus"

, "Account Rights"
: "Fiók jogok"

, "View"
: "Megtekintés"

, "Use"
: "Használ"

, "Tag Name"
: "Címke név"

, "Tag"
: "Címke"

, "Add New Tag"
: "Új címke hozzáadása"

, "Edit Tag \"{0}\""
: "Címke szerkesztése  \"{0}\""

, "Enable Application"
: "Alkalmazás engedélyezése"

, "Disable Application"
: "Alkalmazás letiltása"

, "Settings"
: "Beállítása"

, "{0} Settings"
: "{0} Beállítások"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Alkalmazások megjelenítése {0} - {1} / {2}"

, "No applications to display"
: "Nincs megjeleníthető alkalamazás"

, "Version"
: "Verzió"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Alapértelmezett IMAP felhasználó beállítások"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Konténered megváltozott"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Konténeredet megváltozotta %1$s %2$sFeljegyzés: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""






































, "ImportExportDefinition"
: ""

, "Application"
: "Alkalmazás"

, "User"
: "Felhasználó"

, "Access Log"
: "Hozzáférési Napló"

, "Config"
: ""

, "Container"
: "Konténer"

, "Customfield"
: "Egyedi mező"

, "Group"
: "Csoport"

, "Samba User"
: "Samba User"

, "Email User"
: "Email User"

, "Computer"
: "Számítógép"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
